* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Use Cases and Methodologies](https://help.sap.com/docs/leanix/ea/use-cases-methodologies)
  * SAP ERP Transformation with Integrated Toolchain
